Package: GenomicSuperSignature
Title: Interpretation of RNA-seq experiments through robust, efficient
        comparison to public databases
Authors@R: c(
  person("Sehyun", "Oh", email = "shbrief@gmail.com", role = c("aut","cre")),
  person("Levi", "Waldron", role = "aut"),
  person("Sean", "Davis", email = "seandavi@gmail.com", role = "aut"))
Version: 1.18.0
Date: 2025-9-30
Description: This package provides a novel method for interpreting new 
  transcriptomic datasets through near-instantaneous comparison to public 
  archives without high-performance computing requirements. Through the 
  pre-computed index, users can identify public resources associated with
  their dataset such as gene sets, MeSH term, and publication. Functions to 
  identify interpretable annotations and intuitive visualization options are 
  implemented in this package. 
Depends: R (>= 4.1.0), SummarizedExperiment
Imports: ComplexHeatmap, ggplot2, methods, S4Vectors, Biobase, ggpubr,
        dplyr, plotly, BiocFileCache, grid, flextable, irlba
Suggests: knitr, rmarkdown, devtools, roxygen2, pkgdown, usethis,
        BiocStyle, testthat, forcats, stats, wordcloud, circlize,
        EnrichmentBrowser, clusterProfiler, msigdbr, cluster,
        RColorBrewer, reshape2, tibble, BiocManager, bcellViper, readr,
        utils
License: Artistic-2.0
biocViews: Transcriptomics, SystemsBiology, PrincipalComponent, RNASeq,
        Sequencing, Pathways, Clustering
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.2
VignetteBuilder: knitr
URL: https://github.com/shbrief/GenomicSuperSignature
BugReports: https://github.com/shbrief/GenomicSuperSignature/issues
Collate: 'GenomicSignatures-class.R' 'GenomicSignatures-methods.R'
        'PCAGenomicSignatures-methods.R' 'annotatePC.R' 'annotateRAV.R'
        'availableRAVmodel.R' 'buildAvgLoading.R' 'calculateScore.R'
        'data.R' 'drawWordcloud.R' 'extractPC.R' 'findSignature.R'
        'findStudiesInCluster.R' 'getMetadata.R' 'getModel.R'
        'heatmapTable.R' 'plotAnnotatedPCA.R' 'plotValidate.R'
        'rmNaInf.R' 'sampleScoreHeatmap.R' 'subsetEnrichedPathways.R'
        'utils.R' 'validate.R' 'validatedSignatures.R'
git_url: https://git.bioconductor.org/packages/GenomicSuperSignature
git_branch: RELEASE_3_22
git_last_commit: e2b134e
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-29
NeedsCompilation: no
Packaged: 2025-10-30 04:11:38 UTC; biocbuild
Author: Sehyun Oh [aut, cre],
  Levi Waldron [aut],
  Sean Davis [aut]
Maintainer: Sehyun Oh <shbrief@gmail.com>
