# Generated by roxygen2: do not edit by hand

export("PCAsummary<-")
export("geneSets<-")
export("gsea<-")
export("mesh<-")
export("silhouetteWidth<-")
export("studies<-")
export("trainingData<-")
export("updateNote<-")
export(PCAGenomicSignatures)
export(PCAsummary)
export(PCinRAV)
export(RAVindex)
export(annotatePC)
export(annotateRAV)
export(availableRAVmodel)
export(buildAvgLoading)
export(calculateScore)
export(drawWordcloud)
export(extractPC)
export(findKeywordInRAV)
export(findSignature)
export(findStudiesInCluster)
export(geneSets)
export(getModel)
export(getRAVInfo)
export(getStudyInfo)
export(gsea)
export(heatmapTable)
export(mesh)
export(meshTable)
export(plotAnnotatedPCA)
export(plotValidate)
export(rmNaInf)
export(sampleScoreHeatmap)
export(silhouetteWidth)
export(studies)
export(subsetEnrichedPathways)
export(trainingData)
export(updateNote)
export(validate)
export(validatedSignatures)
export(version)
exportClasses(GenomicSignatures)
exportClasses(PCAGenomicSignatures)
exportMethods("PCAsummary<-")
exportMethods("geneSets<-")
exportMethods("gsea<-")
exportMethods("mesh<-")
exportMethods("silhouetteWidth<-")
exportMethods("studies<-")
exportMethods("trainingData<-")
exportMethods("updateNote<-")
exportMethods(PCAsummary)
exportMethods(RAVindex)
exportMethods(geneSets)
exportMethods(gsea)
exportMethods(mesh)
exportMethods(show)
exportMethods(silhouetteWidth)
exportMethods(studies)
exportMethods(trainingData)
exportMethods(updateNote)
exportMethods(version)
import(ComplexHeatmap)
import(SummarizedExperiment)
import(dplyr)
import(ggplot2)
import(ggpubr)
import(methods)
importFrom(BiocFileCache,bfcadd)
importFrom(BiocFileCache,bfcdownload)
importFrom(BiocFileCache,bfcneedsupdate)
importFrom(BiocFileCache,bfcquery)
importFrom(BiocFileCache,bfcrpath)
importFrom(S4Vectors,metadata)
importFrom(grid,gpar)
importFrom(irlba,irlba)
